package com.clx.performance.sdk.request.action;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

import static com.clx.performance.sdk.constant.ActionConstants.PAYMENT_SETTLEMENT;

/**
 * @Author liruixin
 * @create 2023-09-19 13:33
 */
@Getter
@Setter
@Accessors(chain = true)
public class PaymentSettlementAction implements Action<String>{

    @NotNull(message = "结算单号不能为空")
    @ApiModelProperty(value="结算单号",example = "JS10")
    private String settlementNo;

    @NotBlank(message = "收款人不能为空")
    @ApiModelProperty(value = "收款人", example = "收款人")
    private String payee;

    @NotBlank(message = "收款银行不能为空")
    @ApiModelProperty(value = "收款银行", example = "浙江银行")
    private String payeeBankName;

    @NotBlank(message = "收款银行卡卡号不能为空")
    @ApiModelProperty(value = "收款银行卡卡号", example = "62213545878787")
    private String payeeBankCardNo;

    @NotBlank(message = "付款银行不能为空")
    @ApiModelProperty(value = "付款银行", example = "浙江银行")
    private String paymentBankName;

    @NotBlank(message = "付款银行卡卡号不能为空")
    @ApiModelProperty(value = "付款银行卡卡号", example = "62213545878787")
    private String paymentBankCardNo;


    @NotBlank(message = "付款凭证不能为空")
    @ApiModelProperty(value = "付款凭证", example = "/a.png")
    private String paymentImg;

    @Override
    public String action() {
        return PAYMENT_SETTLEMENT;
    }

}
